; docformat = 'rst'
;+
; This is an example program to demonstrate how to create a GeoTiff image plot
; with Coyote Graphics routines.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "geotiff_image_plot.pro" and run it like this::
;       IDL> .RUN geotiff_image_plot
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 27 January 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO GeoTiff_Image_Plot
 
   ; Set up variables for the plot. Normally, these values would be 
   ; passed into the program as positional and keyword parameters.
   geoTiff_filename = 'AF03sep15b.n16-VIg.tif'
   
   ; Open a display window.
   cgDisplay, 650, 650
   
   ; Set up the colors for the Geotiff image plot. Missing values are 0.
   cgLoadCT, 29, /Brewer, /Reverse, NColors=254, Bottom=1
   TVLCT, cgColor('white', /Triple), 0
   
   ; Get the image and map coordinate information at the same time.
   mapCoord = cgGeoMap(geoTiff_filename, Image=image)
   
   ; Missing values are identified as -10000.0 in this floating image.
   missingIndices = Where(image EQ -10000.0, missingCnt)
   IF missingCnt GT 0 THEN image[missingIndices] = !Values.F_NaN
   
   ; Find the image range and scale the data accordingly.
   minRange = (Floor(Min(image, /NaN) / 1e3) *  1e3 ) > 0
   maxRange = Ceil(Max(image, /NaN) / 1e3) *  1e3
   scaledImage = cgImgScl(image, MinValue=minRange, MaxValue=maxRange)
   
   ; Display the GeoTiff image with continental outlines and a map grid overlaid.
   cgImage, scaledImage, MapCoord=mapCoord, /Keep_Aspect, $
      Position=[0.05, 0.05, 0.95, 0.825], OPosition=opos
      
   ; Add map annotations.
   mapCoord -> SetProperty, /OnImage, /Draw
   cgMap_Continents, Map=mapCoord
   cgMap_Grid, Map=mapCoord, /Label, LatDelta=10, LonDelta=10
   
   ; Add a color bar.
   cgColorbar, Range=[minRange, maxRange], NColors=254, Bottom=1, $
      Position=[opos[0], 0.875, opos[2], 0.925], Title='NVDI Index', $
      TLocation='Top'
      
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  GeoTiff_Image_Plot
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'GeoTiff_Image_Plot', WAspect=1.0, WXSize=650, WYSize=650, $
    WTitle='GeoTiff Image in a Resizeable Graphics Window'
  
  ; Create a PostScript file.
  cgPS_Open, 'geotiff_image_plot.ps'
  GeoTiff_Image_Plot
  cgPS_Close
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'geotiff_image_plot.ps', /PNG, Width=600, /Portrait

END